@@ -382,6 +382,32 @@ assay_facets: Facets = {
         ),
     },
     "ELISA": {"Data": FacetConfig(["/elisa/assay.xlsx"])},
+    "ctDNA": {
+        "Demultiplexed Source BAMs": FacetConfig(
+            ["/ctdna/demultiplexed.bam", "/ctdna/demultiplexed.bam.bai"],
+            "Demultiplexed BAM files (and indexes) generated from circulating tumor DNA.",
+        ),
+        "Genome-wide Plots": FacetConfig(
+            ["/ctdna_analysis/genome-wide_plots.pdf"],
+            "Plots showing Copy Number Alteration (CNA) across the whole genome for all solutions generated by ichorCNA.",
+        ),
+        "Bias / QC Plots": FacetConfig(
+            ["/ctdna_analysis/bias_qc_plots.pdf"],
+            "Plots showing readcount corrections applied by ichorCNA for GC bias and Mappability bias.",
+        ),
+        "Optimal Solutions": FacetConfig(
+            ["/ctdna_analysis/optimal_solution.zip"],
+            "The optimal solution as calculated by ichorCNA.",
+        ),
+        "Other Solutions": FacetConfig(
+            ["/ctdna_analysis/other_solutions.zip"],
+            "Other possible solutions also calculated by ichorCNA.",
+        ),
+        "Batch-level Summary Plots": FacetConfig(
+            ["/ctdna_analysis/summary_plots.pdf"],
+            "Plots showing Copy Number Alteration (CNA) across the whole genome for each sample for the top 2 solutions generated by ichorCNA.",
+        ),
+    },
 }
 
 clinical_facets: Facets = {
@@ -417,6 +443,10 @@ analysis_ready_facets = {
     "WES Assay": FacetConfig(["maf|combined maf"]),
     "TCR": FacetConfig(["/tcr_analysis/report_trial.tar.gz"]),
     "mIF": FacetConfig(["/mif/roi_/cell_seg_data.txt"]),
+    "ctDNA": FacetConfig(
+        ["/ctdna_analysis/summary_plots.pdf"],
+        "Plots showing Copy Number Alteration (CNA) across the whole genome for each sample for the top 2 solutions generated by ichorCNA.",
+    ),
 }
 
 facets_dict: Dict[str, Facets] = {
